summaryrefslogtreecommitdiffstats
path: root/smb4k/core/smb4kpreviewitem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 22:30:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 22:30:35 +0000
commited6e59662040eb15573dae9c323450e9a720ac01 (patch)
treebe17632b1c7c05f3d669eb26b5634edbcb772bb7 /smb4k/core/smb4kpreviewitem.h
parentc0875805b54444a0740d98a6d2c8fa05cd672fef (diff)
downloadsmb4k-ed6e59662040eb15573dae9c323450e9a720ac01.tar.gz
smb4k-ed6e59662040eb15573dae9c323450e9a720ac01.zip
TQt4 port smb4k
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/smb4k@1239034 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'smb4k/core/smb4kpreviewitem.h')
-rw-r--r--smb4k/core/smb4kpreviewitem.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/smb4k/core/smb4kpreviewitem.h b/smb4k/core/smb4kpreviewitem.h
index d3663d5..2ef4f72 100644
--- a/smb4k/core/smb4kpreviewitem.h
+++ b/smb4k/core/smb4kpreviewitem.h
@@ -30,15 +30,15 @@
#include <config.h>
#endif
-// Qt includes
-#include <qstring.h>
-#include <qmap.h>
-#include <qpair.h>
+// TQt includes
+#include <tqstring.h>
+#include <tqmap.h>
+#include <tqpair.h>
// application specific includes
#include "smb4knetworkitems.h"
-typedef QPair<int, QString> ContentsItem;
+typedef TQPair<int, TQString> ContentsItem;
/**
* This class provides a container for the preview of the contents of a remote
@@ -60,7 +60,7 @@ class Smb4KPreviewItem
*
* @param path The path for that the preview should be collected.
*/
- Smb4KPreviewItem( Smb4KShareItem *item, const QString &ip = QString::null, const QString &path = QString::null );
+ Smb4KPreviewItem( Smb4KShareItem *item, const TQString &ip = TQString(), const TQString &path = TQString() );
/**
* The empty constructor.
@@ -75,17 +75,17 @@ class Smb4KPreviewItem
/**
* Returns the workgroup where the host is located
*/
- const QString &workgroup() const { return m_workgroup; }
+ const TQString &workgroup() const { return m_workgroup; }
/**
* Return the name of the host where the share is located.
*/
- const QString &host() const { return m_host; }
+ const TQString &host() const { return m_host; }
/**
* Return the name of the share that is to be previewed.
*/
- const QString &share() const { return m_share; }
+ const TQString &share() const { return m_share; }
/**
* With this function you can set the share name if this item
@@ -94,25 +94,25 @@ class Smb4KPreviewItem
*
* @param share The new share name
*/
- void setShare( const QString &share );
+ void setShare( const TQString &share );
/**
* Return the path that is to be previewed.
*/
- const QString &path() const { return m_path; }
+ const TQString &path() const { return m_path; }
/**
* Returns the IP address of the host where the share
* is located.
*/
- const QString &ip() const { return m_ip; }
+ const TQString &ip() const { return m_ip; }
/**
* Set the IP address of the host.
*
* @param ip The IP address of the host.
*/
- void setIP( const QString &ip );
+ void setIP( const TQString &ip );
/**
* Set the path for which the preview.
@@ -122,7 +122,7 @@ class Smb4KPreviewItem
* @note As soon as this function is used, the list of files and directories
* will be cleared.
*/
- void setPath( const QString &path );
+ void setPath( const TQString &path );
/**
* Returns the current location in the form //HOST/SHARE/PATH.
@@ -130,7 +130,7 @@ class Smb4KPreviewItem
*
* @returns The current location
*/
- const QString &location() const { return m_location; }
+ const TQString &location() const { return m_location; }
/**
* This enumeration is used for the contents. It determines if
@@ -144,12 +144,12 @@ class Smb4KPreviewItem
*
* @returns a map of (hidden) files and (hidden) directories.
*/
- const QValueList<ContentsItem> &contents() const { return m_contents; }
+ const TQValueList<ContentsItem> &contents() const { return m_contents; }
/**
* Add a file or directory to the contents.
*
* @param item A ContentsItem object. This is a QPair<int,QString>
* with the integer being a value from the Contents
* enumeration and the string being the full path of
* the file or directory.
@@ -168,38 +168,38 @@ class Smb4KPreviewItem
/**
* The workgroup of the host
*/
- QString m_workgroup;
+ TQString m_workgroup;
/**
* The host's name
*/
- QString m_host;
+ TQString m_host;
/**
* The share name
*/
- QString m_share;
+ TQString m_share;
/**
* The IP address of the host
*/
- QString m_ip;
+ TQString m_ip;
/**
* The path that has to be previewed.
*/
- QString m_path;
+ TQString m_path;
/**
* The current location
*/
- QString m_location;
+ TQString m_location;
/**
* This map stores the contents of the current
* location.
*/
- QValueList<ContentsItem> m_contents;
+ TQValueList<ContentsItem> m_contents;
/**
* This function checks if the IP address is valid, i.e. the
@@ -210,7 +210,7 @@ class Smb4KPreviewItem
*
* @returns TRUE if the IP address is valid and FALSE otherwise.
*/
- bool ipIsValid( const QString &ip );
+ bool ipIsValid( const TQString &ip );
};
#endif
@@ -144,12 +144,12 @@ class Smb4KPreviewItem
* Add a file or directory to the contents.
*
- * @param item A ContentsItem object. This is a QPair<int,QString>
+ * @param item A ContentsItem object. This is a TQPair<int,TQString>
* with the integer being a value from the Contents
* enumeration and the string being the full path of